@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -164,6 +164,14 @@ namespace KeePass.App.Configuration
 			set { m_bAdjustKeybLayout = value; }
 		}
 
+		private bool m_bAllowInterleaved = false;
+		[DefaultValue(false)]
+		public bool AutoTypeAllowInterleaved
+		{
+			get { return m_bAllowInterleaved; }
+			set { m_bAllowInterleaved = value; }
+		}
+
 		private bool m_bCancelOnWindowChange = false;
 		[DefaultValue(false)]
 		public bool AutoTypeCancelOnWindowChange
