@@ -80,55 +80,6 @@ namespace KeePass.DataExchange
 				false, null, false, fParent);
 		}
 
-		public static bool? Synchronize(PwDatabase pwStorage, IUIOperations uiOps,
-			bool bOpenFromUrl, Form fParent)
-		{
-			if(pwStorage == null) throw new ArgumentNullException("pwStorage");
-			if(!pwStorage.IsOpen) return null;
-			if(!AppPolicy.Try(AppPolicyId.Import)) return null;
-
-			List<IOConnectionInfo> vConnections = new List<IOConnectionInfo>();
-			if(bOpenFromUrl == false)
-			{
-				OpenFileDialogEx ofd = UIUtil.CreateOpenFileDialog(KPRes.Synchronize,
-					UIUtil.CreateFileTypeFilter(null, null, true), 1, null, true,
-					AppDefs.FileDialogContext.Sync);
-
-				if(ofd.ShowDialog() != DialogResult.OK) return null;
-
-				foreach(string strSelFile in ofd.FileNames)
-					vConnections.Add(IOConnectionInfo.FromPath(strSelFile));
-			}
-			else // Open URL
-			{
-				IOConnectionForm iocf = new IOConnectionForm();
-				iocf.InitEx(false, new IOConnectionInfo(), true, true);
-
-				if(UIUtil.ShowDialogNotValue(iocf, DialogResult.OK)) return null;
-
-				vConnections.Add(iocf.IOConnectionInfo);
-				UIUtil.DestroyForm(iocf);
-			}
-
-			return Import(pwStorage, new KeePassKdb2x(), vConnections.ToArray(),
-				true, uiOps, false, fParent);
-		}
-
-		public static bool? Synchronize(PwDatabase pwStorage, IUIOperations uiOps,
-			IOConnectionInfo iocSyncWith, bool bForceSave, Form fParent)
-		{
-			if(pwStorage == null) throw new ArgumentNullException("pwStorage");
-			if(!pwStorage.IsOpen) return null; // No assert or throw
-			if(iocSyncWith == null) throw new ArgumentNullException("iocSyncWith");
-			if(!AppPolicy.Try(AppPolicyId.Import)) return null;
-
-			List<IOConnectionInfo> vConnections = new List<IOConnectionInfo>();
-			vConnections.Add(iocSyncWith);
-
-			return Import(pwStorage, new KeePassKdb2x(), vConnections.ToArray(),
-				true, uiOps, bForceSave, fParent);
-		}
-
 		public static bool? Import(PwDatabase pwDatabase, FileFormatProvider fmtImp,
 			IOConnectionInfo[] vConnections, bool bSynchronize, IUIOperations uiOps,
 			bool bForceSave, Form fParent)
@@ -240,8 +191,6 @@ namespace KeePass.DataExchange
 						UIUtil.DestroyForm(imf);
 					}
 
-					// slf.SetText(KPRes.MergingData, LogStatusType.Info);
-
 					try { pwDatabase.MergeIn(pwImp, mm, dlgStatus); }
 					catch(Exception exMerge)
 					{
@@ -254,19 +203,24 @@ namespace KeePass.DataExchange
 				}
 			}
 
-			dlgStatus.EndLogging();
-
 			if(bSynchronize && bAllSuccess)
 			{
 				Debug.Assert(uiOps != null);
 				if(uiOps == null) throw new ArgumentNullException("uiOps");
 
+				dlgStatus.SetText(KPRes.Synchronizing + " (" +
+					KPRes.SavingDatabase + ")", LogStatusType.Info);
+
 				if(uiOps.UIFileSave(bForceSave))
 				{
 					foreach(IOConnectionInfo ioc in vConnections)
 					{
 						try
 						{
+							// dlgStatus.SetText(KPRes.Synchronizing + " (" +
+							//	KPRes.SavingDatabase + " " + ioc.GetDisplayName() +
+							//	")", LogStatusType.Info);
+
 							if(ioc.Path != pwDatabase.IOConnectionInfo.Path)
 							{
 								if(pwDatabase.IOConnectionInfo.IsLocalFile() &&
@@ -303,9 +257,86 @@ namespace KeePass.DataExchange
 				}
 			}
 
+			dlgStatus.EndLogging();
 			return bAllSuccess;
 		}
 
+		public static bool? Import(PwDatabase pd, FileFormatProvider fmtImp,
+			IOConnectionInfo iocImp, PwMergeMethod mm, CompositeKey cmpKey)
+		{
+			if(pd == null) { Debug.Assert(false); return false; }
+			if(fmtImp == null) { Debug.Assert(false); return false; }
+			if(iocImp == null) { Debug.Assert(false); return false; }
+			if(cmpKey == null) cmpKey = new CompositeKey();
+
+			if(!AppPolicy.Try(AppPolicyId.Import)) return false;
+			if(!fmtImp.TryBeginImport()) return false;
+
+			PwDatabase pdImp = new PwDatabase();
+			pdImp.New(new IOConnectionInfo(), cmpKey);
+			pdImp.MemoryProtection = pd.MemoryProtection.CloneDeep();
+
+			Stream s = IOConnection.OpenRead(iocImp);
+			if(s == null)
+				throw new FileNotFoundException(iocImp.GetDisplayName() +
+					MessageService.NewLine + KPRes.FileNotFoundError);
+
+			try { fmtImp.Import(pdImp, s, null); }
+			finally { s.Close(); }
+
+			pd.MergeIn(pdImp, mm);
+			return true;
+		}
+
+		public static bool? Synchronize(PwDatabase pwStorage, IUIOperations uiOps,
+			bool bOpenFromUrl, Form fParent)
+		{
+			if(pwStorage == null) throw new ArgumentNullException("pwStorage");
+			if(!pwStorage.IsOpen) return null;
+			if(!AppPolicy.Try(AppPolicyId.Import)) return null;
+
+			List<IOConnectionInfo> vConnections = new List<IOConnectionInfo>();
+			if(bOpenFromUrl == false)
+			{
+				OpenFileDialogEx ofd = UIUtil.CreateOpenFileDialog(KPRes.Synchronize,
+					UIUtil.CreateFileTypeFilter(null, null, true), 1, null, true,
+					AppDefs.FileDialogContext.Sync);
+
+				if(ofd.ShowDialog() != DialogResult.OK) return null;
+
+				foreach(string strSelFile in ofd.FileNames)
+					vConnections.Add(IOConnectionInfo.FromPath(strSelFile));
+			}
+			else // Open URL
+			{
+				IOConnectionForm iocf = new IOConnectionForm();
+				iocf.InitEx(false, new IOConnectionInfo(), true, true);
+
+				if(UIUtil.ShowDialogNotValue(iocf, DialogResult.OK)) return null;
+
+				vConnections.Add(iocf.IOConnectionInfo);
+				UIUtil.DestroyForm(iocf);
+			}
+
+			return Import(pwStorage, new KeePassKdb2x(), vConnections.ToArray(),
+				true, uiOps, false, fParent);
+		}
+
+		public static bool? Synchronize(PwDatabase pwStorage, IUIOperations uiOps,
+			IOConnectionInfo iocSyncWith, bool bForceSave, Form fParent)
+		{
+			if(pwStorage == null) throw new ArgumentNullException("pwStorage");
+			if(!pwStorage.IsOpen) return null; // No assert or throw
+			if(iocSyncWith == null) throw new ArgumentNullException("iocSyncWith");
+			if(!AppPolicy.Try(AppPolicyId.Import)) return null;
+
+			List<IOConnectionInfo> vConnections = new List<IOConnectionInfo>();
+			vConnections.Add(iocSyncWith);
+
+			return Import(pwStorage, new KeePassKdb2x(), vConnections.ToArray(),
+				true, uiOps, bForceSave, fParent);
+		}
+
 		public static int CountQuotes(string str, int posMax)
 		{
 			int i = 0, n = 0;
@@ -353,7 +384,7 @@ namespace KeePass.DataExchange
 		public static bool SetStatus(IStatusLogger slLogger, uint uPercent)
 		{
 			if(slLogger != null) return slLogger.SetProgress(uPercent);
-			else return true;
+			return true;
 		}
 
 		private static readonly string[] m_vTitles = {
@@ -372,7 +403,8 @@ namespace KeePass.DataExchange
 			"email", "e-mail", "id", "userid", "user id",
 			"login", "form_loginname", "wpname", "mail",
 			"loginid", "login id", "log",
-			"first name", "last name", "card#",
+			"first name", "last name", "card#", "account #",
+			"member", "member #",
 
 			// Non-English names
 			"nom"
@@ -384,13 +416,14 @@ namespace KeePass.DataExchange
 			"secret", "secret word",
 			"key", "keyword", "key word", "keyphrase", "key phrase",
 			"form_pw", "wppassword", "pin", "pwd", "pw", "pword",
-			"p", "serial", @"serial#", "license key"
+			"p", "serial", "serial#", "license key", "reg #"
 		};
 
 		private static readonly string[] m_vUrls = {
 			"url", "hyper link", "hyperlink", "link",
 			"host", "hostname", "host name", "server", "address",
 			"hyper ref", "href", "web", "website", "web site", "site",
+			"web-site",
 
 			// Non-English names
 			"ort"
@@ -575,7 +608,7 @@ namespace KeePass.DataExchange
 
 			try
 			{
-				if(Clipboard.ContainsText()) return Clipboard.GetText();
+				if(ClipboardUtil.ContainsText()) return ClipboardUtil.GetText();
 			}
 			catch(Exception) { Debug.Assert(false); } // Opened by other process
 
