@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -92,8 +92,17 @@ namespace KeePass.Forms
 			UIUtil.SetFocus(m_tbName, this);
 		}
 
+		private void CleanUpEx()
+		{
+			// Detach event handlers
+			m_lvEvents.SmallImageList = null;
+			m_lvConditions.SmallImageList = null;
+			m_lvActions.SmallImageList = null;
+		}
+
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
 		{
+			CleanUpEx();
 			GlobalWindowManager.RemoveWindow(this);
 		}
 
