@@ -177,12 +177,15 @@ namespace KeePass.Forms
 				"GROUP", "GROUPPATH", "PASSWORD_ENC",
 				"URL:RMVSCM", "URL:SCM", "URL:HOST", "URL:PORT", "URL:PATH",
 				"URL:QUERY",
+				"T-REPLACE-RX:/T/S/R/",
 				"C:Comment", VkcBreak,
-				"DELAY 1000", "DELAY=200", "VKEY 65",
+				"DELAY 1000", "DELAY=200", "VKEY 13", "VKEY-NX 13", "VKEY-EX 13",
 				"PICKCHARS", "PICKCHARS:Password:C=3",
 				"NEWPASSWORD", "HMACOTP", "CLEARFIELD", VkcBreak,
 				"APPDIR", "DB_PATH", "DB_DIR", "DB_NAME", "DB_BASENAME", "DB_EXT",
-				"ENV_DIRSEP", VkcBreak,
+				"ENV_DIRSEP", "ENV_PROGRAMFILES_X86", VkcBreak,
+				// "INTERNETEXPLORER", "FIREFOX", "OPERA", "GOOGLECHROME",
+				// "SAFARI", VkcBreak,
 				"DT_SIMPLE", "DT_YEAR", "DT_MONTH", "DT_DAY", "DT_HOUR", "DT_MINUTE",
 				"DT_SECOND", "DT_UTC_SIMPLE", "DT_UTC_YEAR", "DT_UTC_MONTH",
 				"DT_UTC_DAY", "DT_UTC_HOUR", "DT_UTC_MINUTE", "DT_UTC_SECOND"
