@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,13 +34,13 @@ namespace KeePass.Forms
 	public partial class InternalBrowserForm : Form
 	{
 		private string m_strInitialUrl = string.Empty;
-		private PwGroup m_pgDataSource = null;
+		// private PwGroup m_pgDataSource = null; // See InitEx
 
 		public void InitEx(string strUrl, PwGroup pgDataSource)
 		{
 			if(strUrl != null) m_strInitialUrl = strUrl;
 
-			m_pgDataSource = pgDataSource;
+			// m_pgDataSource = pgDataSource; // Not used yet
 		}
 
 		public InternalBrowserForm()
