@@ -32,9 +32,10 @@ namespace KeePass.UI
 {
 	public sealed class OnDemandStatusDialog : IStatusLogger
 	{
-		private bool m_bUseThread;
+		private readonly bool m_bUseThread;
+		private readonly Form m_fOwner;
+
 		private Thread m_th = null;
-		private Form m_fOwner;
 		private StatusProgressForm m_dlgModal = null;
 		private object m_objSync = new object();
 
@@ -142,7 +143,7 @@ namespace KeePass.UI
 			MainForm mfOwner = ((m_fOwner != null) ? (m_fOwner as MainForm) : null);
 			if((m_bUseThread == false) && (mfOwner != null))
 			{
-				mfOwner.RedirectActivationPush(dlg);
+				// mfOwner.RedirectActivationPush(dlg);
 				mfOwner.UIBlockInteraction(true);
 			}
 
@@ -156,7 +157,7 @@ namespace KeePass.UI
 				MainForm mfOwner = ((m_fOwner != null) ? (m_fOwner as MainForm) : null);
 				if((m_bUseThread == false) && (mfOwner != null))
 				{
-					mfOwner.RedirectActivationPop();
+					// mfOwner.RedirectActivationPop();
 					mfOwner.UIBlockInteraction(false);
 				}
 
