@@ -225,14 +225,22 @@ namespace KeePass.Util
 
 			byte[] pbUuid = MemUtil.HexStringToByteArray(strUuid);
 			if((pbUuid == null) || (pbUuid.Length != PwUuid.UuidSize)) return;
+			PwUuid pwUuid = new PwUuid(pbUuid);
 
-			PwDatabase pdb = mf.ActiveDatabase;
-			if((pdb == null) || !pdb.IsOpen) return;
+			List<PwDocument> lDocs = mf.DocumentManager.GetDocuments(int.MinValue);
+			foreach(PwDocument pwDoc in lDocs)
+			{
+				if(pwDoc == null) { Debug.Assert(false); continue; }
 
-			PwEntry pe = pdb.RootGroup.FindEntry(new PwUuid(pbUuid), true);
-			if(pe == null) return;
+				PwDatabase pdb = pwDoc.Database;
+				if((pdb == null) || !pdb.IsOpen) continue;
 
-			mf.PerformDefaultUrlAction(new PwEntry[]{ pe }, true);
+				PwEntry pe = pdb.RootGroup.FindEntry(pwUuid, true);
+				if(pe == null) continue;
+
+				mf.PerformDefaultUrlAction(new PwEntry[]{ pe }, true);
+				break;
+			}
 		}
 	}
 }
