@@ -92,6 +92,7 @@
 			this.m_tbSave = new System.Windows.Forms.ToolStripButton();
 			this.m_tbSep0 = new System.Windows.Forms.ToolStripSeparator();
 			this.m_tbFind = new System.Windows.Forms.ToolStripTextBox();
+			this.m_menuFileImportPo = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_tabMain.SuspendLayout();
 			this.m_tabProps.SuspendLayout();
 			this.m_tabStrings.SuspendLayout();
@@ -588,14 +589,14 @@
             this.m_menuFileSep1,
             this.m_menuFileExit});
 			this.m_menuFile.Name = "m_menuFile";
-			this.m_menuFile.Size = new System.Drawing.Size(35, 20);
+			this.m_menuFile.Size = new System.Drawing.Size(39, 20);
 			this.m_menuFile.Text = "&File";
 			// 
 			// m_menuFileOpen
 			// 
 			this.m_menuFileOpen.Image = global::TrlUtil.Properties.Resources.B16x16_Folder_Yellow_Open;
 			this.m_menuFileOpen.Name = "m_menuFileOpen";
-			this.m_menuFileOpen.Size = new System.Drawing.Size(123, 22);
+			this.m_menuFileOpen.Size = new System.Drawing.Size(152, 22);
 			this.m_menuFileOpen.Text = "&Open...";
 			this.m_menuFileOpen.Click += new System.EventHandler(this.OnFileOpen);
 			// 
@@ -603,7 +604,7 @@
 			// 
 			this.m_menuFileSave.Image = global::TrlUtil.Properties.Resources.B16x16_FileSave;
 			this.m_menuFileSave.Name = "m_menuFileSave";
-			this.m_menuFileSave.Size = new System.Drawing.Size(123, 22);
+			this.m_menuFileSave.Size = new System.Drawing.Size(152, 22);
 			this.m_menuFileSave.Text = "&Save";
 			this.m_menuFileSave.Click += new System.EventHandler(this.OnFileSave);
 			// 
@@ -611,53 +612,54 @@
 			// 
 			this.m_menuFileSaveAs.Image = global::TrlUtil.Properties.Resources.B16x16_FileSaveAs;
 			this.m_menuFileSaveAs.Name = "m_menuFileSaveAs";
-			this.m_menuFileSaveAs.Size = new System.Drawing.Size(123, 22);
+			this.m_menuFileSaveAs.Size = new System.Drawing.Size(152, 22);
 			this.m_menuFileSaveAs.Text = "Save &As...";
 			this.m_menuFileSaveAs.Click += new System.EventHandler(this.OnFileSaveAs);
 			// 
 			// m_menuFileSep0
 			// 
 			this.m_menuFileSep0.Name = "m_menuFileSep0";
-			this.m_menuFileSep0.Size = new System.Drawing.Size(120, 6);
+			this.m_menuFileSep0.Size = new System.Drawing.Size(149, 6);
 			// 
 			// m_menuFileImport
 			// 
 			this.m_menuFileImport.DropDownItems.AddRange(new System.Windows.Forms.ToolStripItem[] {
             this.m_menuFileImportLng,
+            this.m_menuFileImportPo,
             this.m_menuFileImportSep0,
             this.m_menuFileImport2xNoChecks});
 			this.m_menuFileImport.Name = "m_menuFileImport";
-			this.m_menuFileImport.Size = new System.Drawing.Size(123, 22);
-			this.m_menuFileImport.Text = "Import";
+			this.m_menuFileImport.Size = new System.Drawing.Size(152, 22);
+			this.m_menuFileImport.Text = "&Import";
 			// 
 			// m_menuFileImportLng
 			// 
 			this.m_menuFileImportLng.Name = "m_menuFileImportLng";
-			this.m_menuFileImportLng.Size = new System.Drawing.Size(282, 22);
-			this.m_menuFileImportLng.Text = "KeePass 1.x LNG File...";
+			this.m_menuFileImportLng.Size = new System.Drawing.Size(311, 22);
+			this.m_menuFileImportLng.Text = "KeePass &1.x LNG File...";
 			this.m_menuFileImportLng.Click += new System.EventHandler(this.OnImport1xLng);
 			// 
 			// m_menuFileImportSep0
 			// 
 			this.m_menuFileImportSep0.Name = "m_menuFileImportSep0";
-			this.m_menuFileImportSep0.Size = new System.Drawing.Size(279, 6);
+			this.m_menuFileImportSep0.Size = new System.Drawing.Size(308, 6);
 			// 
 			// m_menuFileImport2xNoChecks
 			// 
 			this.m_menuFileImport2xNoChecks.Name = "m_menuFileImport2xNoChecks";
-			this.m_menuFileImport2xNoChecks.Size = new System.Drawing.Size(282, 22);
-			this.m_menuFileImport2xNoChecks.Text = "KeePass 2.x LNGX File (No Base Checks)...";
+			this.m_menuFileImport2xNoChecks.Size = new System.Drawing.Size(311, 22);
+			this.m_menuFileImport2xNoChecks.Text = "KeePass &2.x LNGX File (No Base Checks)...";
 			this.m_menuFileImport2xNoChecks.Click += new System.EventHandler(this.OnImport2xNoChecks);
 			// 
 			// m_menuFileSep1
 			// 
 			this.m_menuFileSep1.Name = "m_menuFileSep1";
-			this.m_menuFileSep1.Size = new System.Drawing.Size(120, 6);
+			this.m_menuFileSep1.Size = new System.Drawing.Size(149, 6);
 			// 
 			// m_menuFileExit
 			// 
 			this.m_menuFileExit.Name = "m_menuFileExit";
-			this.m_menuFileExit.Size = new System.Drawing.Size(123, 22);
+			this.m_menuFileExit.Size = new System.Drawing.Size(152, 22);
 			this.m_menuFileExit.Text = "&Exit";
 			this.m_menuFileExit.Click += new System.EventHandler(this.OnFileExit);
 			// 
@@ -708,6 +710,13 @@
 			this.m_tbFind.KeyUp += new System.Windows.Forms.KeyEventHandler(this.OnFindKeyUp);
 			this.m_tbFind.TextChanged += new System.EventHandler(this.OnFindTextChanged);
 			// 
+			// m_menuFileImportPo
+			// 
+			this.m_menuFileImportPo.Name = "m_menuFileImportPo";
+			this.m_menuFileImportPo.Size = new System.Drawing.Size(311, 22);
+			this.m_menuFileImportPo.Text = "&PO File...";
+			this.m_menuFileImportPo.Click += new System.EventHandler(this.OnImportPo);
+			// 
 			// MainForm
 			// 
 			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
@@ -809,6 +818,7 @@
 		private System.Windows.Forms.ToolStripSeparator m_menuFileImportSep0;
 		private System.Windows.Forms.ToolStripMenuItem m_menuFileImport2xNoChecks;
 		private System.Windows.Forms.CheckBox m_cbRtl;
+		private System.Windows.Forms.ToolStripMenuItem m_menuFileImportPo;
 	}
 }
 
